@@ -271,11 +271,11 @@ struct PyHandler {
             if (mapping == NULL)
                 return false;
             if (!PyMapping_Check(mapping)) {
+                Py_DECREF(mapping);
                 PyErr_SetString(PyExc_ValueError,
                                 "start_object() must return a mapping instance");
                 return false;
             }
-            Py_INCREF(mapping);
         } else {
             mapping = PyDict_New();
             if (mapping == NULL) {
@@ -317,8 +317,6 @@ struct PyHandler {
         if (replacement == NULL)
             return false;
 
-        Py_INCREF(replacement);
-
         if (!stack.empty()) {
             const HandlerContext& current = stack.back();
 
@@ -356,11 +354,9 @@ struct PyHandler {
             }
         }
         else {
-            Py_DECREF(root);
-            root = replacement;
+            Py_SETREF(root, replacement);
         }
 
-        Py_DECREF(replacement);
         return true;
     }
 
@@ -399,8 +395,6 @@ struct PyHandler {
         if (replacement == NULL)
             return false;
 
-        Py_INCREF(replacement);
-
         if (!stack.empty()) {
             const HandlerContext& current = stack.back();
 
@@ -438,11 +432,9 @@ struct PyHandler {
             }
         }
         else {
-            Py_DECREF(root);
-            root = replacement;
+            Py_SETREF(root, replacement);
         }
 
-        Py_DECREF(replacement);
         return true;
     }
 
@@ -1919,9 +1911,9 @@ dumps_internal(
                 writer->String(isoformat);
             } else /* if (datetimeMode & DM_UNIX_TIME) */ {
                 if (PyDateTime_Check(dtObject)) {
-                    PyObject* timestampObj;
-
-                    timestampObj = PyObject_CallMethodObjArgs(dtObject, timestamp_name, NULL);
+                    PyObject* timestampObj = PyObject_CallMethodObjArgs(dtObject,
+                                                                        timestamp_name,
+                                                                        NULL);
 
                     if (!timestampObj) {
                         Py_XDECREF(asUTC);
